Documentation
¶
Overview ¶
Package postgres implements store.Store using the Grove ORM with pgdriver.
Index ¶
- Variables
- type Store
- func (s *Store) Close() error
- func (s *Store) CountByTenant(ctx context.Context, tenantID string) (int, error)
- func (s *Store) CountDomainsByTenant(ctx context.Context, tenantID string) (int, error)
- func (s *Store) CountSecretsByTenant(ctx context.Context, tenantID string) (int, error)
- func (s *Store) CountTenants(ctx context.Context) (int, error)
- func (s *Store) CountTenantsByStatus(ctx context.Context, status admin.TenantStatus) (int, error)
- func (s *Store) DB() *grove.DB
- func (s *Store) Delete(ctx context.Context, tenantID string, instanceID id.ID) error
- func (s *Store) DeleteCertificate(ctx context.Context, tenantID string, certID id.ID) error
- func (s *Store) DeleteCheck(ctx context.Context, tenantID string, checkID id.ID) error
- func (s *Store) DeleteDomain(ctx context.Context, tenantID string, domainID id.ID) error
- func (s *Store) DeleteRoute(ctx context.Context, tenantID string, routeID id.ID) error
- func (s *Store) DeleteSecret(ctx context.Context, tenantID string, instanceID id.ID, key string) error
- func (s *Store) DeleteTenant(ctx context.Context, tenantID string) error
- func (s *Store) GetByID(ctx context.Context, tenantID string, instanceID id.ID) (*instance.Instance, error)
- func (s *Store) GetBySlug(ctx context.Context, tenantID string, slug string) (*instance.Instance, error)
- func (s *Store) GetCertificate(ctx context.Context, tenantID string, certID id.ID) (*network.Certificate, error)
- func (s *Store) GetCheck(ctx context.Context, tenantID string, checkID id.ID) (*health.HealthCheck, error)
- func (s *Store) GetDeployment(ctx context.Context, tenantID string, deployID id.ID) (*deploy.Deployment, error)
- func (s *Store) GetDomain(ctx context.Context, tenantID string, domainID id.ID) (*network.Domain, error)
- func (s *Store) GetDomainByHostname(ctx context.Context, hostname string) (*network.Domain, error)
- func (s *Store) GetLatestResourceSnapshot(ctx context.Context, tenantID string, instanceID id.ID) (*telemetry.ResourceSnapshot, error)
- func (s *Store) GetLatestResult(ctx context.Context, tenantID string, checkID id.ID) (*health.HealthResult, error)
- func (s *Store) GetRelease(ctx context.Context, tenantID string, releaseID id.ID) (*deploy.Release, error)
- func (s *Store) GetRoute(ctx context.Context, tenantID string, routeID id.ID) (*network.Route, error)
- func (s *Store) GetSecretByKey(ctx context.Context, tenantID string, instanceID id.ID, key string) (*secrets.Secret, error)
- func (s *Store) GetTenant(ctx context.Context, tenantID string) (*admin.Tenant, error)
- func (s *Store) GetTenantBySlug(ctx context.Context, slug string) (*admin.Tenant, error)
- func (s *Store) Insert(ctx context.Context, inst *instance.Instance) error
- func (s *Store) InsertAuditEntry(ctx context.Context, entry *admin.AuditEntry) error
- func (s *Store) InsertCertificate(ctx context.Context, cert *network.Certificate) error
- func (s *Store) InsertCheck(ctx context.Context, check *health.HealthCheck) error
- func (s *Store) InsertDeployment(ctx context.Context, d *deploy.Deployment) error
- func (s *Store) InsertDomain(ctx context.Context, domain *network.Domain) error
- func (s *Store) InsertLogs(ctx context.Context, logs []telemetry.LogEntry) error
- func (s *Store) InsertMetrics(ctx context.Context, metrics []telemetry.Metric) error
- func (s *Store) InsertRelease(ctx context.Context, r *deploy.Release) error
- func (s *Store) InsertResourceSnapshot(ctx context.Context, snap *telemetry.ResourceSnapshot) error
- func (s *Store) InsertResult(ctx context.Context, result *health.HealthResult) error
- func (s *Store) InsertRoute(ctx context.Context, route *network.Route) error
- func (s *Store) InsertSecret(ctx context.Context, secret *secrets.Secret) error
- func (s *Store) InsertTenant(ctx context.Context, tenant *admin.Tenant) error
- func (s *Store) InsertTraces(ctx context.Context, traces []telemetry.Trace) error
- func (s *Store) List(ctx context.Context, tenantID string, opts instance.ListOptions) (*instance.ListResult, error)
- func (s *Store) ListCertificates(ctx context.Context, tenantID string, instanceID id.ID) ([]network.Certificate, error)
- func (s *Store) ListCertificatesByDomain(ctx context.Context, tenantID string, domainID id.ID) ([]network.Certificate, error)
- func (s *Store) ListChecks(ctx context.Context, tenantID string, instanceID id.ID) ([]health.HealthCheck, error)
- func (s *Store) ListDeployments(ctx context.Context, tenantID string, instanceID id.ID, ...) (*deploy.DeployListResult, error)
- func (s *Store) ListDomains(ctx context.Context, tenantID string, instanceID id.ID) ([]network.Domain, error)
- func (s *Store) ListReleases(ctx context.Context, tenantID string, instanceID id.ID, ...) (*deploy.ReleaseListResult, error)
- func (s *Store) ListResourceSnapshots(ctx context.Context, tenantID string, instanceID id.ID, ...) ([]telemetry.ResourceSnapshot, error)
- func (s *Store) ListResults(ctx context.Context, tenantID string, checkID id.ID, ...) ([]health.HealthResult, error)
- func (s *Store) ListRoutes(ctx context.Context, tenantID string, instanceID id.ID) ([]network.Route, error)
- func (s *Store) ListSecrets(ctx context.Context, tenantID string, instanceID id.ID) ([]secrets.Secret, error)
- func (s *Store) ListTenants(ctx context.Context, opts admin.ListTenantsOptions) (*admin.TenantListResult, error)
- func (s *Store) Migrate(ctx context.Context) error
- func (s *Store) NextReleaseVersion(ctx context.Context, tenantID string, instanceID id.ID) (int, error)
- func (s *Store) Ping(ctx context.Context) error
- func (s *Store) QueryAuditLog(ctx context.Context, opts admin.AuditQuery) (*admin.AuditResult, error)
- func (s *Store) QueryLogs(ctx context.Context, q telemetry.LogQuery) ([]telemetry.LogEntry, error)
- func (s *Store) QueryMetrics(ctx context.Context, q telemetry.MetricQuery) ([]telemetry.Metric, error)
- func (s *Store) QueryTraces(ctx context.Context, q telemetry.TraceQuery) ([]telemetry.Trace, error)
- func (s *Store) Update(ctx context.Context, inst *instance.Instance) error
- func (s *Store) UpdateCertificate(ctx context.Context, cert *network.Certificate) error
- func (s *Store) UpdateCheck(ctx context.Context, check *health.HealthCheck) error
- func (s *Store) UpdateDeployment(ctx context.Context, d *deploy.Deployment) error
- func (s *Store) UpdateDomain(ctx context.Context, domain *network.Domain) error
- func (s *Store) UpdateRoute(ctx context.Context, route *network.Route) error
- func (s *Store) UpdateSecret(ctx context.Context, secret *secrets.Secret) error
- func (s *Store) UpdateTenant(ctx context.Context, tenant *admin.Tenant) error
Constants ¶
This section is empty.
Variables ¶
var Migrations = migrate.NewGroup("ctrlplane")
Migrations is the grove migration group for the CtrlPlane store.
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
Store implements store.Store using grove ORM with pgdriver.
func (*Store) CountByTenant ¶ added in v0.1.0
func (*Store) CountDomainsByTenant ¶ added in v0.1.0
func (*Store) CountSecretsByTenant ¶ added in v0.1.0
func (*Store) CountTenants ¶ added in v0.1.0
func (*Store) CountTenantsByStatus ¶ added in v0.1.0
func (*Store) DeleteCertificate ¶ added in v0.1.0
func (*Store) DeleteCheck ¶ added in v0.1.0
func (*Store) DeleteDomain ¶ added in v0.1.0
func (*Store) DeleteRoute ¶ added in v0.1.0
func (*Store) DeleteSecret ¶ added in v0.1.0
func (*Store) DeleteTenant ¶ added in v0.1.0
func (*Store) GetCertificate ¶ added in v0.1.0
func (*Store) GetDeployment ¶ added in v0.1.0
func (*Store) GetDomainByHostname ¶ added in v0.1.0
func (*Store) GetLatestResourceSnapshot ¶ added in v0.1.0
func (*Store) GetLatestResult ¶ added in v0.1.0
func (*Store) GetRelease ¶ added in v0.1.0
func (*Store) GetSecretByKey ¶ added in v0.1.0
func (*Store) GetTenantBySlug ¶ added in v0.1.0
func (*Store) InsertAuditEntry ¶ added in v0.1.0
func (*Store) InsertCertificate ¶ added in v0.1.0
func (*Store) InsertCheck ¶ added in v0.1.0
func (*Store) InsertDeployment ¶ added in v0.1.0
func (*Store) InsertDomain ¶ added in v0.1.0
func (*Store) InsertLogs ¶ added in v0.1.0
func (*Store) InsertMetrics ¶ added in v0.1.0
func (*Store) InsertRelease ¶ added in v0.1.0
func (*Store) InsertResourceSnapshot ¶ added in v0.1.0
func (*Store) InsertResult ¶ added in v0.1.0
func (*Store) InsertRoute ¶ added in v0.1.0
func (*Store) InsertSecret ¶ added in v0.1.0
func (*Store) InsertTenant ¶ added in v0.1.0
func (*Store) InsertTraces ¶ added in v0.1.0
func (*Store) List ¶ added in v0.1.0
func (s *Store) List(ctx context.Context, tenantID string, opts instance.ListOptions) (*instance.ListResult, error)
func (*Store) ListCertificates ¶ added in v0.1.0
func (*Store) ListCertificatesByDomain ¶ added in v0.1.0
func (*Store) ListChecks ¶ added in v0.1.0
func (*Store) ListDeployments ¶ added in v0.1.0
func (*Store) ListDomains ¶ added in v0.1.0
func (*Store) ListReleases ¶ added in v0.1.0
func (*Store) ListResourceSnapshots ¶ added in v0.1.0
func (*Store) ListResults ¶ added in v0.1.0
func (*Store) ListRoutes ¶ added in v0.1.0
func (*Store) ListSecrets ¶ added in v0.1.0
func (*Store) ListTenants ¶ added in v0.1.0
func (s *Store) ListTenants(ctx context.Context, opts admin.ListTenantsOptions) (*admin.TenantListResult, error)
func (*Store) Migrate ¶
Migrate creates the required tables and indexes using the grove orchestrator.
func (*Store) NextReleaseVersion ¶ added in v0.1.0
func (*Store) QueryAuditLog ¶ added in v0.1.0
func (s *Store) QueryAuditLog(ctx context.Context, opts admin.AuditQuery) (*admin.AuditResult, error)
func (*Store) QueryMetrics ¶ added in v0.1.0
func (*Store) QueryTraces ¶ added in v0.1.0
func (*Store) UpdateCertificate ¶ added in v0.1.0
func (*Store) UpdateCheck ¶ added in v0.1.0
func (*Store) UpdateDeployment ¶ added in v0.1.0
func (*Store) UpdateDomain ¶ added in v0.1.0
func (*Store) UpdateRoute ¶ added in v0.1.0
func (*Store) UpdateSecret ¶ added in v0.1.0
Click to show internal directories.
Click to hide internal directories.